summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE20
-rw-r--r--CHANGES4
-rw-r--r--CMakeLists.txt2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--configure.ac4
-rw-r--r--contrib/libtests/pngunknown.c2
-rw-r--r--contrib/libtests/pngvalid.c2
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.316
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c8
-rw-r--r--png.h18
-rw-r--r--pngconf.h2
-rw-r--r--pngread.c2
-rw-r--r--pngtest.c2
-rw-r--r--pngwrite.c2
-rw-r--r--pngwutil.c2
-rw-r--r--projects/vstudio/README.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt10
-rw-r--r--scripts/def.c2
-rw-r--r--scripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt4
-rw-r--r--scripts/symbols.def2
30 files changed, 70 insertions, 66 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index fd6855b28..444c265d0 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.26beta02 - October 1, 2016
+Libpng 1.6.26beta03 - October 2, 2016
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -8,20 +8,20 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.6.26beta02.tar.xz (LZMA-compressed, recommended)
- 1.6.26beta02.tar.gz
+ 1.6.26beta03.tar.xz (LZMA-compressed, recommended)
+ 1.6.26beta03.tar.gz
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1626b02.7z (LZMA-compressed, recommended)
- lp1626b02.zip
+ lp1626b03.7z (LZMA-compressed, recommended)
+ lp1626b03.zip
Other information:
- 1.6.26beta02-README.txt
- 1.6.26beta02-LICENSE.txt
- libpng-1.6.26beta02-*.asc (armored detached GPG signatures)
+ 1.6.26beta03-README.txt
+ 1.6.26beta03-LICENSE.txt
+ libpng-1.6.26beta03-*.asc (armored detached GPG signatures)
Changes since the last public release (1.6.25):
@@ -41,7 +41,7 @@ Version 1.6.26beta01 [September 26, 2016]
Add tests/badcrc.png and tests/badadler.png to tests/pngtest.
Merged pngtest.c with libpng-1.7.0beta84/pngtest.c
-Version 1.6.26beta02 [October 1, 2016]
+Version 1.6.26beta02 [September 30, 2016]
Updated the documentation about CRC and ADLER32 handling.
Quieted 117 warnings from clang-3.8 in pngtrans.c, pngread.c,
pngwrite.c, pngunknown.c, and pngvalid.c.
@@ -49,6 +49,8 @@ Version 1.6.26beta02 [October 1, 2016]
flag definitions in pngpriv.h from 0xnnnn to 0xnnnnU and trivial changes
in png.c, pngread.c, and pngwutil.c.
+Version 1.6.26beta03 [October 2, 2016]
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CHANGES b/CHANGES
index ec63af516..a52e98381 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5719,7 +5719,7 @@ Version 1.6.26beta01 [September 26, 2016]
Add tests/badcrc.png and tests/badadler.png to tests/pngtest.
Merged pngtest.c with libpng-1.7.0beta84/pngtest.c
-Version 1.6.26beta02 [October 1, 2016]
+Version 1.6.26beta02 [September 30, 2016]
Updated the documentation about CRC and ADLER32 handling.
Quieted 117 warnings from clang-3.8 in pngtrans.c, pngread.c,
pngwrite.c, pngunknown.c, and pngvalid.c.
@@ -5727,6 +5727,8 @@ Version 1.6.26beta02 [October 1, 2016]
flag definitions in pngpriv.h from 0xnnnn to 0xnnnnU and trivial changes
in png.c, pngread.c, and pngwutil.c.
+Version 1.6.26beta03 [October 2, 2016]
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 0d9dd2cdc..24781d1e3 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -696,7 +696,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(png PROPERTIES
-# VERSION 16.${PNGLIB_RELEASE}.1.6.26beta02
+# VERSION 16.${PNGLIB_RELEASE}.1.6.26beta03
VERSION 16.${PNGLIB_RELEASE}.0
SOVERSION 16
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index e38a3af4e..772fba627 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000 through 1.6.26beta02, October 1, 2016 are
+libpng versions 1.0.7, July 1, 2000 through 1.6.26beta03, October 2, 2016 are
Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
@@ -127,4 +127,4 @@ any encryption software. See the EAR, paragraphs 734.3(b)(3) and
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-October 1, 2016
+October 2, 2016
diff --git a/README b/README
index c7a5f075b..b3f0626af 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.26beta02 - October 1, 2016 (shared library 16.0)
+README for libpng version 1.6.26beta03 - October 2, 2016 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure.ac b/configure.ac
index 047e06bc4..da763f76e 100644
--- a/configure.ac
+++ b/configure.ac
@@ -25,7 +25,7 @@ AC_PREREQ([2.68])
dnl Version number stuff here:
-AC_INIT([libpng],[1.6.26beta02],[png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng],[1.6.26beta03],[png-mng-implement@lists.sourceforge.net])
AC_CONFIG_MACRO_DIR([scripts])
# libpng does not follow GNU file name conventions (hence 'foreign')
@@ -46,7 +46,7 @@ dnl automake, so the following is not necessary (and is not defined anyway):
dnl AM_PREREQ([1.11.2])
dnl stop configure from automagically running automake
-PNGLIB_VERSION=1.6.26beta02
+PNGLIB_VERSION=1.6.26beta03
PNGLIB_MAJOR=1
PNGLIB_MINOR=6
PNGLIB_RELEASE=26
diff --git a/contrib/libtests/pngunknown.c b/contrib/libtests/pngunknown.c
index d20d112e8..b27b07563 100644
--- a/contrib/libtests/pngunknown.c
+++ b/contrib/libtests/pngunknown.c
@@ -1,7 +1,7 @@
/* pngunknown.c - test the read side unknown chunk handling
*
- * Last changed in libpng 1.6.22 [May 26, 2016]
+ * Last changed in libpng 1.6.26 [(PENDING RELEASE)]
* Copyright (c) 2015,2016 Glenn Randers-Pehrson
* Written by John Cunningham Bowler
*
diff --git a/contrib/libtests/pngvalid.c b/contrib/libtests/pngvalid.c
index 2f2be9ec0..1c45b615a 100644
--- a/contrib/libtests/pngvalid.c
+++ b/contrib/libtests/pngvalid.c
@@ -1,7 +1,7 @@
/* pngvalid.c - validate libpng by constructing then reading png files.
*
- * Last changed in libpng 1.6.24 [August 4, 2016]
+ * Last changed in libpng 1.6.26 [(PENDING RELEASE)]
* Copyright (c) 2014-2016 Glenn Randers-Pehrson
* Written by John Cunningham Bowler
*
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 931a2a1c5..26ed23169 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.26beta02 - October 1, 2016
+ libpng version 1.6.26beta03 - October 2, 2016
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2016 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.26beta02 - October 1, 2016
+ libpng versions 0.97, January 1998, through 1.6.26beta03 - October 2, 2016
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2016 Glenn Randers-Pehrson
@@ -5354,7 +5354,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.26beta02 are Y2K compliant. It is my belief that earlier
+upward through 1.6.26beta03 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
diff --git a/libpng.3 b/libpng.3
index e8c73d81e..3d25bcee4 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "October 1, 2016"
+.TH LIBPNG 3 "October 2, 2016"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.26beta02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.26beta03
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -510,7 +510,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.26beta02 - October 1, 2016
+ libpng version 1.6.26beta03 - October 2, 2016
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2016 Glenn Randers-Pehrson
@@ -521,7 +521,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.26beta02 - October 1, 2016
+ libpng versions 0.97, January 1998, through 1.6.26beta03 - October 2, 2016
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2016 Glenn Randers-Pehrson
@@ -5864,7 +5864,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.26beta02 are Y2K compliant. It is my belief that earlier
+upward through 1.6.26beta03 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -6022,7 +6022,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.26beta02 - October 1, 2016:
+Libpng version 1.6.26beta03 - October 2, 2016:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6047,7 +6047,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000 through 1.6.26beta02, October 1, 2016 are
+libpng versions 1.0.7, July 1, 2000 through 1.6.26beta03, October 2, 2016 are
Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
@@ -6172,7 +6172,7 @@ files "pngbar.png" and "pngbar.jpg (88x31) and "pngnow.png" (98x31).
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-October 1, 2016
+October 2, 2016
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 0d9183694..55faf467c 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "October 1, 2016"
+.TH LIBPNGPF 3 "October 2, 2016"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.26beta02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.26beta03
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 6f1f3110e..c527c1bb3 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "October 1, 2016"
+.TH PNG 5 "October 2, 2016"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 921724b1f..50dfd2480 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * Last changed in libpng 1.6.25 [September 1, 2016]
+ * Last changed in libpng 1.6.26 [(PENDING RELEASE)]
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_26beta02 Your_png_h_is_not_version_1_6_26beta02;
+typedef png_libpng_version_1_6_26beta03 Your_png_h_is_not_version_1_6_26beta03;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -775,14 +775,14 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.26beta02 - October 1, 2016" PNG_STRING_NEWLINE \
+ "libpng version 1.6.26beta03 - October 2, 2016" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson" \
PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.26beta02 - October 1, 2016\
+ return "libpng version 1.6.26beta03 - October 2, 2016\
Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index f3f72cdb3..09c59b09b 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.26beta02, October 1, 2016
+ * libpng version 1.6.26beta03, October 2, 2016
*
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index 85ca2353c..09b099c80 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
/* pngread.c - read a PNG file
*
- * Last changed in libpng 1.6.24 [August 4, 2016]
+ * Last changed in libpng 1.6.26 [(PENDING RELEASE)]
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtest.c b/pngtest.c
index 78c434411..4c292f792 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -2083,4 +2083,4 @@ main(void)
#endif
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_26beta02 Your_png_h_is_not_version_1_6_26beta02;
+typedef png_libpng_version_1_6_26beta03 Your_png_h_is_not_version_1_6_26beta03;
diff --git a/pngwrite.c b/pngwrite.c
index db6ff61a7..ff940b6dc 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
/* pngwrite.c - general routines to write a PNG file
*
- * Last changed in libpng 1.6.24 [August 4, 2016]
+ * Last changed in libpng 1.6.26 [(PENDING RELEASE)]
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwutil.c b/pngwutil.c
index 4f1cc37cd..7514f8ed6 100644
--- a/pngwutil.c
+++ b/pngwutil.c
@@ -1,7 +1,7 @@
/* pngwutil.c - utilities to write a PNG file
*
- * Last changed in libpng 1.6.24 [August 4, 2016]
+ * Last changed in libpng 1.6.26 [(PENDING RELEASE)]
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/projects/vstudio/README.txt b/projects/vstudio/README.txt
index 4ba0fc536..55c04aab1 100644
--- a/projects/vstudio/README.txt
+++ b/projects/vstudio/README.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.26beta02 - October 1, 2016
+libpng version 1.6.26beta03 - October 2, 2016
Copyright (c) 2010,2013,2015 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 89ca9c8d0..da616888b 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.26beta02 - October 1, 2016
+ * libpng version 1.6.26beta03 - October 2, 2016
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 494a2d7b1..8d7cbf4ff 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.6.26beta02 - October 1, 2016
+Makefiles for libpng version 1.6.26beta03 - October 2, 2016
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng16.so.16.1.6.26beta02)
+ (gcc, creates libpng16.so.16.1.6.26beta03)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -33,12 +33,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng16.so.16.1.6.26beta02)
+ creates libpng16.so.16.1.6.26beta03)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng16.so.16.1.6.26beta02)
+ creates libpng16.so.16.1.6.26beta03)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng16.so.16.1.6.26beta02)
+ creates libpng16.so.16.1.6.26beta03)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/def.c b/scripts/def.c
index 88479f10c..ebace1f1e 100644
--- a/scripts/def.c
+++ b/scripts/def.c
@@ -21,7 +21,7 @@ PNG_DFN "OS2 DESCRIPTION "PNG image compression library""
PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
PNG_DFN ""
PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.6.26beta02"
+PNG_DFN ";Version 1.6.26beta03"
#define PNG_EXPORTA(ordinal, type, name, args, attributes)\
PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 0c6c0b2fc..b2e9b7f2b 100644
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.6.26beta02
+version=1.6.26beta03
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 0a65964b5..ee9d33411 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng16
Name: libpng
Description: Loads and saves PNG files
-Version: 1.6.26beta02
+Version: 1.6.26beta03
Libs: -L${libdir} -lpng16
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 10626b94c..25bee1756 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng16
LIB= png16
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.6.26beta02
+SHLIB_MINOR= 1.6.26beta03
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 4e73994f7..72c9a2a04 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.26beta02
+SHLIB_MINOR= 1.6.26beta03
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 0567d7645..e1f229719 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.26beta02
+SHLIB_MINOR= 1.6.26beta03
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 20990cd04..f10cf6c0b 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,8 +1,8 @@
-/* libpng 1.6.26beta02 STANDARD API DEFINITION */
+/* libpng 1.6.26beta03 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.26beta02 - October 1, 2016 */
+/* Libpng version 1.6.26beta03 - October 2, 2016 */
/* Copyright (c) 1998-2015 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index d3f99ed7b..c931fc060 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.6.26beta02
+;Version 1.6.26beta03
;--------------------------------------------------------------
; LIBPNG symbol list as a Win32 DEF file
; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index 0820db0a1..31a3659bf 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.26beta02, October 1, 2016
*
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.26beta02, October 1, 2016:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
*/
@@ -29,7 +29,7 @@
* files that are distributed with libpng have other copyright owners and
* are released under other open source licenses.
*
* libpng versions 1.0.7, July 1, 2000 through 1.6.26beta02, October 1, 2016 are
* Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
* disclaimer and license as libpng-1.0.6 with the following individuals
@@ -246,13 +246,13 @@
* Y2K compliance in libpng:
* =========================
*
- * October 1, 2016
+ * October 2, 2016
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.26beta02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -314,8 +314,8 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.26beta02"
-#define PNG_HEADER_VERSION_STRING " libpng version 1.6.26beta02 - October 1, 2016\n"
+#define PNG_LIBPNG_VER_STRING "1.6.26beta03"
+#define PNG_HEADER_VERSION_STRING " libpng version 1.6.26beta03 - October 2, 2016\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -329,7 +329,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 02
+#define PNG_LIBPNG_VER_BUILD 03
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -464,7 +464,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_26beta02;
+typedef char* png_libpng_version_1_6_26beta03;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.26beta02, October 1, 2016
+ * libpng version 1.6.26beta03, October 2, 2016
*
* Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.26beta02, October 1, 2016:
+ * libpng versions 0.97, January 1998, through 1.6.26beta03, October 2, 2016:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
@@ -29,7 +29,7 @@
* are released under other open source licenses.
*
- * libpng versions 1.0.7, July 1, 2000 through 1.6.26beta02, October 1, 2016 are
+ * libpng versions 1.0.7, July 1, 2000 through 1.6.26beta03, October 2, 2016 are
* Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
@@ -246,13 +246,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.26beta02 are Y2K compliant. It is my belief that
+ * upward through 1.6.26beta03 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*